#
# spec file for package openarena
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# The binaries filenames postfix defining:
%ifarch %ix86
%define postfix i386
%else
%ifarch armv6l armv6hl
%define postfix armv6l
%else
%ifarch armv7l armv7hl
%define postfix armv7l
%else
%define postfix %{_target_cpu}
%endif
%endif
%endif
Name:           openarena
Version:        0.8.8
Release:        bp154.1.47
Summary:        Open Arena game engine
License:        GPL-2.0+
Group:          Amusements/Games/Action/Shoot
Url:            http://openarena.ws/
Source0:        http://files.poulsander.com/~poul19/public_files/oa/dev088/%{name}-engine-source-%{version}.tar.bz2
Source1:        %{name}.desktop
Source2:        %{name}.svg
Source99:       %{name}.changes
# PATCH-FIX-UPSTREAM to prevent stack.
Patch0:         openarena-0.8.8-stack.patch
# PATCH-FIX-UPSTREAM fix build with newer gcc
Patch1:         fix-compile-gcc5.patch
Patch2:         q_platform_aarch64_support.diff
BuildRequires:  Mesa-devel
BuildRequires:  SDL-devel
BuildRequires:  autoconf >= 2.60
BuildRequires:  libvorbis-devel
BuildRequires:  openal-soft-devel
BuildRequires:  update-desktop-files
Requires:       openarena-data = %{version}
Recommends:     openarena-doc = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
OpenArena is an open-source content package for Quake III Arena
licensed under the GPL, effectively creating a free stand-alone game.

%prep
%setup -q -n %{name}-engine-source-%{version}
%patch0 -p1
%patch1 -p1
%patch2 -p0
# FIX usage of __DATE__
modified="$(sed -n '/^----/n;s/ - .*$//;p;q' "%{SOURCE99}")"
DATE="\"$(date -d "${modified}" "+%%b %%e %%Y")\""
sed -i "s/__DATE__/$DATE/g" code/qcommon/common.c code/sys/sys_main.c

%build
# START of configuration of building ----------------
export CFLAGS="%{optflags}" # C flags for compiler
export USE_OPENAL=1            # We want openAL
export USE_OPENAL_DLOPEN=1     # Next we want to bind openAL on runtime.
                               # SDL sound will be used if openAL is not installed
export USE_CODEC_VORBIS=1      # We want vorbis support
export BUILD_STANDALONE=1      # Open Arena is a standalone game
export DEFAULT_BASEDIR=%{_datadir}/games/openarena  # Where is directory with openarena-data
# END of configuration of building -----------------------------
make %{?_smp_mflags} V=1

%install
make copyfiles COPYDIR=%{buildroot}/%{_libexecdir}/%{name}  # Where will come compiled engine files
mkdir -p %{buildroot}/%{_bindir}
install -dm755 %{buildroot}/%{_libexecdir}/%{name}
install -m 755 build/release-linux*/o*%{postfix} %{buildroot}/%{_libexecdir}/%{name}
ln -sf %{_libexecdir}/%{name}/openarena.%{postfix} %{buildroot}%{_bindir}/%{name}
ln -sf %{_libexecdir}/%{name}/oa_ded.%{postfix} %{buildroot}%{_bindir}/%{name}-ded
# Icon, it is simple official icon
install -D -m 644 %{SOURCE2} %{buildroot}/%{_datadir}/pixmaps/%{name}.svg
# Desktop entry
install -D -m 644 %{SOURCE1} %{buildroot}/%{_datadir}/applications/%{name}.desktop
%suse_update_desktop_file %{name}

%files
%defattr(-,root,root)
%{_libexecdir}/%{name}
%{_bindir}/openarena*
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.svg

%changelog
* Thu Mar 29 2018 kasimir_@outlook.de
- Fixed armv6 build
* Fri May 19 2017 stefan.bruens@rwth-aachen.de
- Add q_platform_aarch64_support.diff to fix compilation on aarch64
* Tue May 24 2016 rpm@fthiessen.de
- Added fix-compile-gcc5.patch to fix build on Tumbleweed (gcc5)
- Fixed some warnings (like usage of __DATE__)
* Sun Sep 15 2013 dap.darkness@gmail.com
- Arm build was fixed.
* Wed Dec 26 2012 joop.boonen@boonen.org
- openal-devel is now called openal-soft-devel
* Sun Aug 12 2012 dap.darkness@gmail.com
- updated to 0.8.8
- licence tag was fixed
- existed patch became useless and was removed
- a stack patch was added
- "Recommends" doc package instead of "Requires"
* Fri Mar 23 2012 jengelh@medozas.de
- Fix syntax error near %%ifarch
- Have files owned by root - there is no reason to use "games"
* Sat Jul  2 2011 jengelh@medozas.de
- Use %%_smp_mflags for parallel building
- Strip %%clean section (not needed on BS)
* Sat Nov 27 2010 jslaby@suse.de
- fix bot laoding failure (wrong strcpy usage)
* Mon Jan 19 2009 michal.smrz@opensuse.cz
- updated to 0.8.1
- changed build procedure, 'cause upstream changed it
- no patch is now needed (to successful build)
- documentation is no longer included in this package
- added .desktop file and .svg icon
* Mon Aug 11 2008 lmichnovic@suse.cz
- hardcoded games data dir which is /usr/share/games/openarena/
  (hardcode_data_path.patch)
* Mon Aug 11 2008 lmichnovic@suse.cz
- fixed libdir
* Mon Aug 11 2008 lmichnovic@suse.cz
- update to version 0.8
  * 3 new maps, 3 new weapons, bug fixes
* Thu Jun  5 2008 lmichnovic@suse.cz
- update to version 0.7.7
- not yet fixed date files search PATH
* Fri Apr 25 2008 lmichnovic@suse.cz
- update to 0.7.6
- New player model : Assassin. This guy kills for greed.
- New player model : Space Marine. This guy serves his Corps. In SPACE.
- New player skin : Angelyss/Neko. Mew!!!!!! :3
- New player skin : Grism/Indigo. A homage of that other game.
- Ayumi/Neko, Angelyss/Sly have been atticed due to quality reasons.
- Text font (bigchars.tga) used by console and hud messages now
  doesn't bleed anymore.
- Special characters added for text font (bigchars.tga) used by
  some mods. If you've ever encountered a "?" where it shouldn't
  be in a mod, this should really fix it
- lots of maps and changed maps, at least 8 new significant maps
  to play! This includes the  reworked oa_dm3 and oa_dm5.
- oa_ctf2 is more balanced, slightly retextured.
- Elimination and CTF elimination game types. No one respawns
  until the round is over.
- Double domination game type. Two teams must control two points
  on the map for 10 seconds to score.
- Last Man Standing game type. The name of the game is self
  explanatory.
- Instant Gib option, gives everyone only a railgun that does
  kills instantly.
- All Rockets option, makes everyone only have a rocket launcher.
- Alt-tab working.
- Unlagged tracehits option, provides a more responsive feel for
  railguns, machineguns and shotguns.
- Classic Grism aren't teamskins anymore. This means the 'white'
  skin will not show up during team games. In addition, the skins
  can be used for FFA again.
- Completely in SDL.
- BFG BFG BFG BFG
- A lot of other stuff we forgot like minor polishings. There's
  lots of it and too many to mention here.
* Tue Mar  4 2008 lmichnovic@suse.cz
- update to version 0.7.1
* Thu Nov  8 2007 lmichnovic@suse.cz
- compiling from sources now
  which needed *docu.patch, *makefile.patch, *missing_menudef.patch
